(*
 * Demo for cdplay.library
 *
 * 25.12.99: (thomas@igracki.de)
 *           first version, it works!
 *
 * 03.06.01: v1.1 (thomas@Igracki.de)
 *           added support for cddb.library
 *           QUERY now has two additional parameters: 'dTitle' returns the disc-title, 'tTitle' the current track-title
 *)
MODULE CDP;
IMPORT
   y: SYSTEM, e: Exec, d: Dos,
   tb: ToolBox, st: Strings,
   ez: EzRexx, cd: CDPlay, cddb;

CONST
   tmp = "D=DEVICE/A,U=UNIT/A/N"
         "\o$VER: CDP 1.1 (03.06.01) by Thomas@Igracki.de";

TYPE
   OnOffArgs = STRUCT (dummy: ez.EzRexxArgs)
     on, off: ez.ArgBool;
   END;

   JumpArgs = STRUCT (dummy: ez.EzRexxArgs)
     offset: ez.ArgLong;
   END;

   PlayArgs = STRUCT (dummy: ez.EzRexxArgs)
     track: ez.ArgLong;
   END;
   
   QueryArgs = STRUCT (dummy: ez.EzRexxArgs)
    cap,
    toc,
    time,
    id,
    active,
    track,    
    addr,
    discID,
    dTitle,
    tTitle,
    artist
          : ez.ArgBool;
    
   END;

VAR
   RD  	: d.RDArgsPtr;
   args : STRUCT (dummy: d.ArgsStruct)
      device	: d.ArgString;
      unit  	: ez.ArgLong;
   END;

   req		: cd.RequestPtr;
   rxSig	: SHORTINT;
   WaitSigs, ls	: LONGSET;
   QUIT		: BOOLEAN;

PROCEDURE * RexxOpen (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN     cd.open(req)
END RexxOpen;

PROCEDURE * RexxClose (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN     cd.close(req)
END RexxClose;

PROCEDURE * RexxStop (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN     cd.stop (req)
END RexxStop;

PROCEDURE * RexxNext (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN     cd.next (req)
END RexxNext;

PROCEDURE * RexxPrev (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN     cd.prev (req)
END RexxPrev;

PROCEDURE * RexxLock (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN
  WITH args: OnOffArgs DO
     IF    args.on  = d.DOSTRUE THEN cd.lockDrive (1, req);
     ELSIF args.off = d.DOSTRUE THEN cd.lockDrive (0, req);
     END;
  END;
END RexxLock;

PROCEDURE * RexxPause (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN
  WITH args: OnOffArgs DO
     IF    args.on  = d.DOSTRUE THEN cd.pause (1, req);
     ELSIF args.off = d.DOSTRUE THEN cd.pause (0, req);
     END;
  END;
END RexxPause;

PROCEDURE * RexxPlay (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
VAR track: LONGINT;
BEGIN
  WITH args: PlayArgs DO
     IF args.track # NIL THEN
        track := args.track^;
        IF track > 99 THEN track := 99 ELSIF track < 1 THEN track := 1 END;
     ELSE
        track := 1;
     END;
     cd.play (track, req);
  END;
END RexxPlay;

PROCEDURE * RexxJump (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN
  WITH args: JumpArgs DO
     IF args.offset # NIL THEN
        cd.jump (args.offset^, req);
     END;
  END;
END RexxJump;

PROCEDURE * RexxQuery (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
TYPE 
   tTitleStrPtr = UNTRACED POINTER TO ARRAY cddb.maxLenTTitle OF CHAR;
VAR
   t: LONGINT; temp: ARRAY 100 OF CHAR; track: cd.Track; pos1,pos2: LONGINT;

   (* for cddb.library *)
   err     : LONGINT;
   cdi     : cddb.CDInfo;
   discID  : LONGINT;
   categ   : ARRAY cddb.maxLenCateg OF CHAR;
   artist  : ARRAY cddb.maxLenArtist OF CHAR;
   dTitle  : ARRAY cddb.maxLenDTitle OF CHAR;
   tTitles : ARRAY cddb.maxTracks OF tTitleStrPtr;
   ErrStr  : e.STRPTR;
BEGIN
  WITH args: QueryArgs DO
     IF    args.cap = d.DOSTRUE THEN
        tb.Format (result, "Capacity: maxSector = %lD, sectorSize = %lD, capacity = %lD bytes\n", req.capacity.maxSector,req.capacity.sectorSize, req.capacity.capacity);
     ELSIF args.toc = d.DOSTRUE THEN
       IF cddb.base # NIL THEN

          cd.update(req);
          FOR t := req.toc.firstTrack-1 TO req.toc.lastTrack DO
            cdi.msf[t].min  := SHORT(SHORT(cd.BASE2MIN(req.toc.track[t+1].position)));
            cdi.msf[t].sec  := SHORT(SHORT(cd.BASE2SEC(req.toc.track[t+1].position)))+2;
            (* d.PrintF ("%02ld: min/sec = %02ld/%02ld\n", t, cdi.msf[t].min, cdi.msf[t].sec); *)
            (* cdi.msf[t].frame wird nicht bentigt! *)
          END;
          cdi.tracks := req.toc.lastTrack; cdi.time := req.time.allCompleteBase DIV 75;
          cddb.CalcDiscID (cdi);
          (* d.PrintF ("tracks = %ld, time = %ld secs, discID %08lx\n", cdi.tracks, cdi.time, cdi.discID); *)
          FOR t := 0 TO cdi.tracks-1 DO NEW(tTitles[t]) END;

          err := cddb.GetCDDB(y.ADR(cdi),
           cddb.aDiscID, y.ADR(discID),
           cddb.aCateg,  y.ADR(categ),
           cddb.aArtist, y.ADR(artist),
           cddb.aDTitle, y.ADR(dTitle),
           cddb.aTTitles,y.ADR(tTitles),
           0);
          IF err = cddb.errNoError THEN
             IF    args.discID = d.DOSTRUE THEN tb.Format (result, "%08lx", cdi.discID)
             ELSIF args.dTitle = d.DOSTRUE THEN COPY(dTitle,result)
             ELSIF (args.tTitle = d.DOSTRUE) & (req.currentTrack > 0) & (req.currentTrack < req.toc.lastTrack) THEN COPY(tTitles[req.currentTrack-1]^,result)
             ELSIF args.artist = d.DOSTRUE THEN COPY(artist,result)
             END;
          ELSE
             d.PrintF (""); cddb.ErrorStr(err, ErrStr);
             tb.Format (result, "CDDB-Error: %s(%ld)", ErrStr, err);
          END;
        END; (* IF cddb.base # NIL *)

        result := "TOC\n";
        IF (cddb.base # NIL) & (err = cddb.errNoError) THEN
           tb.Format (result, "TOC from %s/%s (%08lx)\n", y.ADR(artist), y.ADR(dTitle), discID);
        ELSE
           result := "TOC\n";
        END;
        FOR t := req.toc.firstTrack TO req.toc.lastTrack DO
           track := req.toc.track[t]; 
           pos1 := req.toc.track[t+1].position; pos2 := req.toc.track[t].position;
           IF (cddb.base # NIL) & (err = cddb.errNoError) THEN
              tb.Format (temp, "%02ld: %02ld:%02ld %s\n", t, cd.BASE2MIN(pos1-pos2), cd.BASE2SEC(pos1-pos2), tTitles[t-1]);
           ELSE
              tb.Format (temp, "%02ld: %02ld:%02ld\n", t, cd.BASE2MIN(pos1-pos2), cd.BASE2SEC(pos1-pos2));
           END;
           st.Append (result, temp);
        END;

        IF cddb.base # NIL THEN
           FOR t := 0 TO cdi.tracks-1 DO DISPOSE(tTitles[t]) END;
        END;
     ELSIF args.time   = d.DOSTRUE THEN
      cd.update(req);
      tb.Format (result, "Time:\n  Track: %02ld:%02ld/%02ld:%02ld, remain %02ld:%02ld\n  CD   : %02ld:%02ld/%02ld:%02ld, remain %02ld:%02ld\n",
         cd.BASE2MIN(req.time.trackCurBase),     cd.BASE2SEC(req.time.trackCurBase),
         cd.BASE2MIN(req.time.trackCompleteBase),cd.BASE2SEC(req.time.trackCompleteBase),
         cd.BASE2MIN(req.time.trackRemainBase),  cd.BASE2SEC(req.time.trackRemainBase),
         cd.BASE2MIN(req.time.allCurBase),     cd.BASE2SEC(req.time.allCurBase),
         cd.BASE2MIN(req.time.allCompleteBase),cd.BASE2SEC(req.time.allCompleteBase),
         cd.BASE2MIN(req.time.allRemainBase),  cd.BASE2SEC(req.time.allRemainBase)
         );
     ELSIF args.id     = d.DOSTRUE THEN tb.Format (result, "ID %s", y.ADR(req.id));
     ELSIF args.active = d.DOSTRUE THEN cd.update(req); tb.Format (result, "active %ld", req.active);
     ELSIF args.track  = d.DOSTRUE THEN cd.update(req); tb.Format (result, "current track %ld", req.currentTrack);
     ELSIF args.addr   = d.DOSTRUE THEN cd.update(req); tb.Format (result, "current address %02ld:%02ld", cd.BASE2MIN(req.currentAddress), cd.BASE2SEC(req.currentAddress));
     ELSIF (args.discID = d.DOSTRUE) OR (args.dTitle = d.DOSTRUE) OR (args.tTitle = d.DOSTRUE) OR (args.artist = d.DOSTRUE) THEN 
       IF cddb.base = NIL THEN tb.Format (result, "Error: cddb.library not found!");  RETURN END;

       cd.update(req);
       FOR t := 0 TO req.toc.lastTrack DO
         cdi.msf[t].min  := SHORT(SHORT(cd.BASE2MIN(req.toc.track[t+1].position)));
         cdi.msf[t].sec  := SHORT(SHORT(cd.BASE2SEC(req.toc.track[t+1].position)))+2;
         (* d.PrintF ("%02ld: min/sec = %02ld/%02ld\n", t, cdi.msf[t].min, cdi.msf[t].sec); *)
         (* cdi.msf[t].frame wird nicht bentigt! *)
       END;
       cdi.tracks := req.toc.lastTrack; cdi.time := req.time.allCompleteBase DIV 75;
       cddb.CalcDiscID (cdi);
       (* d.PrintF ("tracks = %ld, time = %ld secs, discID %08lx\n", cdi.tracks, cdi.time, cdi.discID); *)
       FOR t := 0 TO cdi.tracks-1 DO NEW(tTitles[t]) END;

       err := cddb.GetCDDB(y.ADR(cdi),
        cddb.aDiscID, y.ADR(discID),
        cddb.aCateg,  y.ADR(categ),
        cddb.aArtist, y.ADR(artist),
        cddb.aDTitle, y.ADR(dTitle),
        cddb.aTTitles,y.ADR(tTitles),
        0);
       IF err = cddb.errNoError THEN
          IF    args.discID = d.DOSTRUE THEN tb.Format (result, "%08lx", cdi.discID)
          ELSIF args.dTitle = d.DOSTRUE THEN COPY(dTitle,result)
          ELSIF (args.tTitle = d.DOSTRUE) & (req.currentTrack > 0) & (req.currentTrack < req.toc.lastTrack) THEN COPY(tTitles[req.currentTrack-1]^,result)
          ELSIF args.artist = d.DOSTRUE THEN COPY(artist,result)
          END;
       ELSE
          d.PrintF (""); cddb.ErrorStr(err, ErrStr);
          tb.Format (result, "CDDB-Error: %s(%ld)", ErrStr, err);
       END;
       FOR t := 0 TO cdi.tracks-1 DO DISPOSE(tTitles[t]) END;
     END;
  END;
END RexxQuery;

PROCEDURE * RexxQuit (args: ez.EzRexxArgsPtr; VAR result: ARRAY OF CHAR); (* $CopyArrays- *)
BEGIN     QUIT := TRUE;
END RexxQuit;

PROCEDURE InstallARexxServer*(): SHORTINT;
VAR sig: SHORTINT;
BEGIN
     IF ~(ez.EasyAddCommand ("OPEN",  "",           RexxOpen, FALSE) & 
          ez.EasyAddCommand ("CLOSE", "",           RexxClose, FALSE) & 
          ez.EasyAddCommand ("STOP",  "",           RexxStop, FALSE) & 
          ez.EasyAddCommand ("NEXT",  "",           RexxNext, FALSE) & 
          ez.EasyAddCommand ("PREV",  "",           RexxPrev, FALSE) & 
          ez.EasyAddCommand ("LOCK",  "ON/S,OFF/S", RexxLock, FALSE) & 
          ez.EasyAddCommand ("PAUSE", "ON/S,OFF/S", RexxPause, FALSE) & 
          ez.EasyAddCommand ("PLAY",  "Track/N",    RexxPlay, FALSE) & 
          ez.EasyAddCommand ("JUMP",  "Offset/N",   RexxJump, FALSE) & 
          ez.EasyAddCommand ("QUERY", "C=Capacity/S,T=TOC/S,M=Time/S,ID/S,Active/S,Track/S,Addr/S,DiscID/S,DT=DiskTitle/S,TT=TrackTitle/S,Artist/S",   RexxQuery, FALSE) & 
          ez.EasyAddCommand ("QUIT",  "",           RexxQuit, FALSE)
         ) THEN
         d.PrintF ("Failed to add arexx commands!\n"); HALT(d.fail)
     END;

     sig := ez.OpenRexx ('CDPLAYER', NIL);
     IF sig = -1 THEN d.PrintF ("Failed to install ARexxPort 'CDPLAYER'!\n"); HALT(d.fail) END;
     RETURN sig
END InstallARexxServer;

BEGIN
     RD := d.ReadArgs (tmp,args,NIL); IF RD = NIL THEN y.SETREG(0,d.PrintFault(d.IoErr(),NIL)); HALT(d.fail) END;

     req := cd.OpenDrive (args.device^, args.unit^); 
     IF req = NIL THEN
        d.PrintF ("Failed to open '%s' unit %ld!\n\n"
                  "Maybe the cd-tray is open or you didn't have a disc inserted!\n", args.device, args.unit^);
        HALT(d.warn);
     END;

     rxSig := InstallARexxServer();
     WaitSigs := LONGSET{rxSig, d.ctrlC};

     (* IF args.gui = d.DOSTRUE THEN OpenWin END; INCL(WaitSigs, win.userPort.sigBit); *)

     QUIT := FALSE;
     REPEAT

        ls := e.Wait (WaitSigs);
        IF rxSig  IN ls THEN ez.HandleRexx() END;

	IF d.ctrlC IN ls THEN QUIT := TRUE END;

     UNTIL QUIT;
     
CLOSE
     IF req # NIL THEN cd.closeDrive (req) END;
     IF RD  # NIL THEN d.FreeArgs (RD) END;
END CDP.
